# mosaicpy 
Python module that actively queries the **Modern Ocean Sediment Archive and Inventory of Carbon (MOSAIC)** database (v.2.0).\
\
[MOSAIC](www.mosaic.ethz.ch) is a is a curated and harmonized database of marine sediment data, centered in carbon (organic and inorganic carbon), its isotopic composition (δ13C and Δ14C), organic matter compounds (e.g., total nitrogen, lignin phenols, fatty acids, and alkanes), and sedimentological properties (e.g., grain size fractions and mineral surface area).

## Installation
Under construction

## Usage example
Under construction

## Release History
* 0.0.1 (March 2024)
    * New release of mosaicpy, work in progress

## About us
* Authors: Sarah Paradis
* Cite us: [Paradis, S., Nakajima, K., Van der Voort, T. S., Gies, H., Wildberger, A., Blattmann, T. M., Bröder, L., and Eglinton, T. I.: The Modern Ocean Sediment Archive and Inventory of Carbon (MOSAIC): version 2.0, Earth Syst. Sci. Data, 15, 4105–4125, doi:10.5194/essd-15-4105-2023, 2023.](https://essd.copernicus.org/articles/15/4105/2023/essd-15-4105-2023.html)